import cdk = require('@aws-cdk/cdk');
import { ILogGroup } from './log-group';
export interface ILogStream extends cdk.IConstruct {
    /**
     * The name of this log stream
     */
    readonly logStreamName: string;
    /**
     * Export this LogStream
     */
    export(): LogStreamImportProps;
}
/**
 * Properties for importing a LogStream
 */
export interface LogStreamImportProps {
    readonly logStreamName: string;
}
/**
 * Properties for a LogStream
 */
export interface LogStreamProps {
    /**
     * The log group to create a log stream for.
     */
    readonly logGroup: ILogGroup;
    /**
     * The name of the log stream to create.
     *
     * The name must be unique within the log group.
     *
     * @default Automatically generated
     */
    readonly logStreamName?: string;
    /**
     * Retain the log stream if the stack or containing construct ceases to exist
     *
     * Normally you want to retain the log stream so you can diagnose issues
     * from logs even after a deployment that no longer includes the log stream.
     *
     * The date-based retention policy of your log group will age out the logs
     * after a certain time.
     *
     * @default true
     */
    readonly retainLogStream?: boolean;
}
/**
 * Define a Log Stream in a Log Group
 */
export declare class LogStream extends cdk.Construct implements ILogStream {
    /**
     * Import an existing LogGroup
     */
    static import(scope: cdk.Construct, id: string, props: LogStreamImportProps): ILogStream;
    /**
     * The name of this log stream
     */
    readonly logStreamName: string;
    constructor(scope: cdk.Construct, id: string, props: LogStreamProps);
    /**
     * Export this LogStream
     */
    export(): LogStreamImportProps;
}
